==> dl.php?src=linea21_1_7.zip: linea21/languages/fr/lang_sdi.utf-8.php <==
<?php
/**
 * @package linea21.languages
 * @subpackage fr
 * @author linea21 <info@linea21.com>
 * @version $id SVN
 * @access public
 * @license http://opensource.org/licenses/gpl-3.0.html
 */



/*	nommage des modules
 *  	*/
$lang['sdi']['name']="indicateur";
$lang['sdi']['confirm_add'] = "Ajout de l'indicateur réalisé avec succès";
$lang['sdi']['confirm_mod'] = "Modification de l'indicateur réalisée avec succès";
$lang['sdi']['confirm_clone'] = "Indicateur cloné avec succès";
$lang['sdi']['confirm_sup'] ="Suppression de l'indicateur réalisée avec succès";


$lang['sdi']['p_name']="fournisseur";
$lang['sdi']['p_confirm_mod'] = "Modification du fournisseur réalisée avec succès";
$lang['sdi']['p_confirm_sup'] ="Suppression du fournisseur réalisée avec succès";


$lang['sdi']['r_name']="réglementation";
$lang['sdi']['r_confirm_mod'] = "Modification de la  réglementation réalisée avec succès";
$lang['sdi']['r_confirm_sup'] ="Suppression de la réglementation réalisée avec succès";


$lang['sdi']['e_name']="évaluation";
$lang['sdi']['e_confirm_mod'] = "Modification de l'évaluation réalisée avec succès";
$lang['sdi']['e_confirm_sup'] ="Suppression de l'évaluation réalisée avec succès";


/*	nommage rubrique module
 *  	*/
$lang['sdi']['add']= "Ajout d'un ".$lang['sdi']['name'];


$lang['sdi']['mod']= "Modification des infos générales";
$lang['sdi']['clone']= "Cloner l'indicateur";
$lang['sdi']['sup']= "Suppression d'un ".$lang['sdi']['name'];


$lang['sdi']['mod_e']= "Modification d'une ".$lang['sdi']['e_name'];
$lang['sdi']['sup_e']= "Suppression d'une ".$lang['sdi']['e_name'];


$lang['sdi']['mod_p']= "Modification d'un ".$lang['sdi']['p_name'];
$lang['sdi']['sup_p']= "Suppression d'un ".$lang['sdi']['p_name'];


$lang['sdi']['mod_r']= "Modification d'une ".$lang['sdi']['r_name'];
$lang['sdi']['sup_r']= "Suppression d'une ".$lang['sdi']['r_name'];


$lang['sdi']['det']= "Détails de l'".$lang['sdi']['name'];
$lang['sdi']['list']= "Liste des indicateurs";


/*	nommage rubrique add / mod /det
 *  	*/
$lang['sdi']['add_title1']="Saisie des informations générales du nouvel ".$lang['sdi']['name'];
$lang['sdi']['add_title2']="Saisie des critères d'évaluation du nouvel ".$lang['sdi']['name'];
$lang['sdi']['add_title3']="Saisie des coordonnées du fournisseur du nouvel ".$lang['sdi']['name'];
$lang['sdi']['add_title4']="Saisie du texte de réglementation du nouvel ".$lang['sdi']['name'];


$lang['sdi']['mod_title']="Modification des informations générales de :";
$lang['sdi']['mod_title2']="Modification des critères d'évaluation  de :";
$lang['sdi']['mod_title3']="Modification des coordonnées du fournisseur de :";
$lang['sdi']['mod_title4']="Modification du texte de réglementation de :";


$lang['sdi']['recap_commment']="aucun commentaire";
$lang['sdi']['confirmation']="confirmer l'inscription";




/*	nommage étapes add
 *  	*/

$lang['sdi']['add_step1']="infos générales";
$lang['sdi']['add_step2']="critères d'évaluation";
$lang['sdi']['add_step3']="coordonnées fournisseur";
$lang['sdi']['add_step4']="texte de réglementation";
$lang['sdi']['btn_step1']="étape2";
$lang['sdi']['btn_step2']="étape3";
$lang['sdi']['btn_step3']="étape4";
$lang['sdi']['btn_fin']="finir saisie";


/*	nommage rubrique sup
 *  	*/
$lang['sdi']['sup_sdi_warning']="Etes-vous sûr de vouloir supprimer définitivement cet ".$lang['sdi']['name']."?";
$lang['sdi']['sup_sdi_warning2']="La suppression de cet indicateur induit la suppression de son fournisseur, du texte de réglementation, de ses valeurs associées, et de ses critères d'évaluation.";
$lang['sdi']['sup_sdi_warning3']="Attention, si vous supprimez cet indicateur, son thème associé ne contiendra plus d'indicateurs.";
/*	nommage élément rubrique
 *  	*/

$lang['sdi']['name2']="nom de l'indicateur";
$lang['sdi']['type']="type d'indicateur";
$lang['sdi']['dashboard_viz']="type de visualisation - tableau de bord";
$lang['sdi']['detail_viz']="type de visualisation - détail";
$lang['sdi']['description']="Description";
$lang['sdi']['comment']="Commentaires";
$lang['sdi']['theme']="thème de rattachement";
$lang['sdi']['range']="Rang de l'indicateur";
$lang['sdi']['goal']="Objectif de l'indicateur (mesures à prendre)";
$lang['sdi']['consulting']="Conseils d'amélioration";
$lang['sdi']['attached_to_dashboard']="Attaché au tableau de bord";
$lang['sdi']['not_attached_to_dashboard']="non attaché au tableau de bord";
$lang['sdi']['info_mesure']="Informations de mesure";
$lang['sdi']['unit']="unité de mesure";
$lang['sdi']['max_value']="maximum";
$lang['sdi']['min_value']="minimum";
$lang['sdi']['initial_threshold_value']="valeur seuil initiale";
$lang['sdi']['threshold_value']="valeur seuil";
$lang['sdi']['threshold_relative']="comportement relatif du seuil";
$lang['sdi']['threshold_relative_comment']="Cochez cette case, si l'objectif est atteint pour une valeur supérieure au seuil.";
$lang['sdi']['threshold_relative_Y']="l'objectif est atteint si la valeur est supérieure au seuil.";
$lang['sdi']['threshold_relative_N']="l'objectif n'est pas atteint si la valeur est supérieure au seuil.";
$lang['sdi']['frequency']="fréquence de collecte";


$lang['sdi']['e_title']="Critères d'évaluation des données";
$lang['sdi']['e_scale_compare']="comparabilité";
$lang['sdi']['e_fiability']="fiabilité";
$lang['sdi']['e_accessibility']="accessibilité";
$lang['sdi']['e_lisibility']="lisibilité";
$lang['sdi']['e_relevance']="pertinence";
$lang['sdi']['e_global_performance']="performance globale";


$lang['sdi']['p_title']="fournisseur des données";
$lang['sdi']['p_name']="nom du fournisseur";
$lang['sdi']['p_service']="service";
$lang['sdi']['p_description']="description du fournisseur";
$lang['sdi']['p_incharge']="responsable";
$lang['sdi']['p_address']="adresse complète";
$lang['sdi']['p_phone']="téléphone";
$lang['sdi']['p_fax']="fax";
$lang['sdi']['p_email']="email";


$lang['sdi']['r_title']="nom de la réglementation";
$lang['sdi']['r_body']="texte de réglementation";
$lang['sdi']['r_referer_uri']="lien internet";
$lang['sdi']['r_mask_uri']="texte de lien";


/** select-box option and values (keys) */
$lang['sdi']['select_type']['quantitative']='quantitatif';
$lang['sdi']['select_type']['qualitative']='qualitatif';
$lang['sdi']['select_dashboard_viz']['raw']='valeur brute';
$lang['sdi']['select_dashboard_viz']['gauge']='jauge';
$lang['sdi']['select_dashboard_viz']['sparkline']='sparkline';
$lang['sdi']['select_detail_viz']['column']='colonne';
$lang['sdi']['select_detail_viz']['line']='ligne';
$lang['sdi']['select_detail_viz']['area']='aire';


/*	nommage quickbox
 *  	*/
$lang['sdi']['qb_add_title']=" derniers ajouts effectués";
$lang['sdi']['qb_mod_title']=" dernières modifications effectuées";


/*	divers
 *  	*/
$lang['sdi']['select_choice']="-- Faites votre choix dans la liste ci dessous --";
$lang['sdi']['facultatif']="facultatif";
$lang['sdi']['theme_filter']="Afficher par thème";
$lang['sdi']['notheme']="Aucun thème choisi";
$lang['sdi']['aff_sdi_e']="Afficher les critères d'évaluation";
$lang['sdi']['modify_sdi_e']="Modifier les critères d'évaluation";

$lang['sdi']['aff_sdi_r']="Afficher les textes de réglementation";
$lang['sdi']['modify_sdi_r']="Modifier les textes de réglementation";
$lang['sdi']['aff_sdi_p']="Afficher les coordonnées du fournisseur";
$lang['sdi']['modify_sdi_p']="Modifier les coordonnées du fournisseur";
$lang['sdi']['noresultp']="Vous pouvez saisir un fournisseur en cliquant sur le bouton modifier ci contre";
$lang['sdi']['noresultr']="Vous pouvez saisir un texte de réglementation en cliquant sur le bouton modifier ci contre";
$lang['sdi']['url']='<acronym title="Uniform Resource Locator">URL</acronym>';
$lang['sdi']['clone_suffix']= "clone";

/*	messages
 *  	*/


$lang['sdi']['object_notname']="Vous devez impérativement saisir un nom pour cet indicateur.";
$lang['sdi']['object_notdescription']="Vous devez impérativement saisir une description pour cet indicateur.";
$lang['sdi']['object_nottheme']="Vous devez impérativement choisir un thème pour cet indicateur.";
$lang['sdi']['object_notrange']="Vous devez impérativement choisir un rang pour cet indicateur.";
$lang['sdi']['object_notunit']="Vous devez impérativement saisir une unité de mesure.";
$lang['sdi']['object_notmax_value']="La valeur maximale doit être une valeur numérique.";
$lang['sdi']['object_notmin_value']="La valeur minimale doit être une valeur numérique.";
$lang['sdi']['object_notthreshold_value']="La valeur de seuil doit être une valeur numérique.";
$lang['sdi']['object_notfrequency']="La fréquence de relevé doit être une valeur numérique.";
$lang['sdi']['server_noresponse']='L\' '.$lang['sdi']['url'].' semble incorrecte (le fichier ne répond pas). Veuillez vérifier sa syntaxe';




$lang['sdi']['object_note_scale_compare']="L'indice de comparabilité doit être une valeur numérique.";
$lang['sdi']['object_note_fiability']="L'indice de fiabilité doit être une valeur numérique.";
$lang['sdi']['object_note_accessibility']="L'indice d'accessibilité doit être une valeur numérique.";
$lang['sdi']['object_note_lisibility']="L'indice de lisibilité doit être une valeur numérique.";
$lang['sdi']['object_note_relevance']="L'indice de pertinence doit être une valeur numérique.";
$lang['sdi']['object_note_global_performance']="L'indice de performance globale doit être une valeur numérique.";




$lang['sdi']['object_notp_name']="Vous devez impérativement entrer un nom pour ce fournisseur.";
$lang['sdi']['object_notp_address']="Vous devez impérativement entrer une adresse pour ce fournisseur.";
$lang['sdi']['object_notp_phone']="Le numéro de téléphone n'est pas valide.";
$lang['sdi']['object_notp_fax']="Le numéro de fax n'est pas valide.";
$lang['sdi']['object_notp_mail']="L'adresse email n'est pas valide.";


$lang['sdi']['object_notr_title']="Vous devez impérativement entrer un nom pour cette réglementation.";

$lang['sdi']['object_notr_body']="Vous devez impérativement entrer un texte pour cette réglementation.";


/*	rubrique d'aide
 *  	*/
$lang['sdi']['help_add1']="Pour ajouter un indicateur, vous devez saisir chacun de ces paramètres dans le formulaire ci-dessus";
$lang['sdi']['help_add2']="l'ajout d'un indicateur se réalise en 4 étapes : infos générales -> évaluation -> fournisseur -> réglementation";
$lang['sdi']['help_add3']="Après avoir valider le formulaire d'ajout, vérifiez les paramètres d'ajout dans le récapitulatif";
$lang['sdi']['help_add4']="Si le récapitulatif ne vous convient pas, vous pouvez cliquer sur \"revoir les paramètres\" pour les modifier";
$lang['sdi']['help_add5']="Vous pouvez ne pas remplir les 3 denières étapes en cliquant sur '".$lang['sdi']['btn_fin']."' à la première étape, vous serez alors directement redirigé vers le récapitulatif";
$lang['sdi']['help_add6']="Les champs marqués d'un astérisque sont obligatoires";


$lang['sdi']['help_list1']="Pour afficher un indicateur en détails, cliquez sur le nom de cet indicateur";
$lang['sdi']['help_list2']="Vous pouvez supprimer un indicateur en cliquant sur l'icône de suppression associée";
$lang['sdi']['help_list3']="Vous pouvez modifier un indicateur en cliquant sur l'icône de modification associée";
$lang['sdi']['help_list4']="Pour ajouter un indicateur, cliquez sur le lien \"ajouter un indicateur\" dans la barre de titre";
$lang['sdi']['help_list5']="Vous pouvez faire une recherche dans la liste d'indicateurs à tout moment en cliquant sur \"recherche\"";

$lang['sdi']['help_mod1']="Pour modifier les informations générales d'un indicateur, vous pouvez modifier chacun de ces paramètres dans le formulaire ci-dessus";
$lang['sdi']['help_mod2']="Après avoir validé le formulaire de modification, vérifiez les paramètres d'ajout dans le récapitulatif";
$lang['sdi']['help_mod3']="Si le récapitulatif ne vous convient pas, vous pouvez cliquer sur \"revoir les paramètres\" pour les modifier";
$lang['sdi']['help_mod4']="Pour modifier les informations de réglementation, fournisseurs, et critères d'évaluation, cliquer sur \"modifier ces informations\" en haut de page.";
$lang['sdi']['help_mod5']="Pour modifier les informations générales de cet indicateur, cliquer sur l'icône de modification qui lui est associée sur la page \"détails d'un indicateur\".";


$lang['sdi']['help_mod_p1']="Pour modifier les coordonnées fournisseurs d'un indicateur, vous pouvez modifier chacun de ces paramètres dans le formulaire ci-dessus";
$lang['sdi']['help_mod_e1']="Pour modifier les critères d'évaluation d'un indicateur, vous pouvez modifier chacun de ces paramètres dans le formulaire ci-dessus";
$lang['sdi']['help_mod_r1']="Pour modifier les textes de réglementation d'un indicateur, vous pouvez modifier chacun de ces paramètres dans le formulaire ci-dessus";


$lang['sdi']['help_det1']="Vous pouvez modifier les informations générales de cet indicateur en cliquant sur l'icône de modification associée";
$lang['sdi']['help_det2']="Vous pouvez supprimer cet indicateur en cliquant sur l'icône de suppression associée";
$lang['sdi']['help_det3']="Pour afficher le thème de l'indicateur consulté, cliquez sur le nom de ce thème";
$lang['sdi']['help_det4']="Pour afficher les informations de réglementation, fournisseurs, et critères d'évaluation, cliquer sur \"afficher ces informations\" en bas de page";
$lang['sdi']['help_det5']="Pour modifier les informations de réglementation, fournisseurs, et critères d'évaluation, cliquer sur les icônes de modification associées";


$lang['sdi']['help_sup1']="En cliquant sur valider, l'indicateur est définitivement suppprimer ainsi que son fournisseur, son texte de réglementation, ses valeurs associées, et ses critères d'évaluation";
$lang['sdi']['help_sup2']="Un message apparait si le thème associé à cet indicateur ne contient plus d'indicateurs après suppression de celui-ci";
?>

==> dl.php?src=linea21_1_8.zip: linea21/languages/fr/lang_sdi.utf-8.php <==
<?php
/**
 * @package linea21\languages\fr
 * @author $Author$ - linea21 <info@linea21.com>
 * @version $Id$ 
 * @access public
 * @license http://opensource.org/licenses/gpl-3.0.html
 */



/*	nommage des modules
 *  	*/
$lang['sdi']['name']="indicateur";
$lang['sdi']['confirm_add'] = "Ajout de l'indicateur réalisé avec succès";
$lang['sdi']['confirm_mod'] = "Modification de l'indicateur réalisée avec succès";
$lang['sdi']['confirm_clone'] = "Indicateur cloné avec succès";
$lang['sdi']['confirm_sup'] ="Suppression de l'indicateur réalisée avec succès";


$lang['sdi']['p_name']="fournisseur";
$lang['sdi']['p_confirm_mod'] = "Modification du fournisseur réalisée avec succès";
$lang['sdi']['p_confirm_sup'] ="Suppression du fournisseur réalisée avec succès";


$lang['sdi']['r_name']="réglementation";
$lang['sdi']['r_confirm_mod'] = "Modification de la  réglementation réalisée avec succès";
$lang['sdi']['r_confirm_sup'] ="Suppression de la réglementation réalisée avec succès";


$lang['sdi']['e_name']="évaluation";
$lang['sdi']['e_confirm_mod'] = "Modification de l'évaluation réalisée avec succès";
$lang['sdi']['e_confirm_sup'] ="Suppression de l'évaluation réalisée avec succès";


/*	nommage rubrique module
 *  	*/
$lang['sdi']['add']= "Ajout d'un ".$lang['sdi']['name'];


$lang['sdi']['mod']= "Modifier les infos générales";
$lang['sdi']['clone']= "Cloner l'indicateur";
$lang['sdi']['sup']= "Suppression de l'".$lang['sdi']['name'];


$lang['sdi']['mod_e']= "Modification d'une ".$lang['sdi']['e_name'];
$lang['sdi']['sup_e']= "Suppression d'une ".$lang['sdi']['e_name'];


$lang['sdi']['mod_p']= "Modification d'un ".$lang['sdi']['p_name'];
$lang['sdi']['sup_p']= "Suppression d'un ".$lang['sdi']['p_name'];


$lang['sdi']['mod_r']= "Modification d'une ".$lang['sdi']['r_name'];
$lang['sdi']['sup_r']= "Suppression d'une ".$lang['sdi']['r_name'];


$lang['sdi']['det']= "Détails de l'".$lang['sdi']['name'];
$lang['sdi']['list']= "Liste des indicateurs";


/*	nommage rubrique add / mod /det
 *  	*/
$lang['sdi']['add_title1']="Saisie des informations générales du nouvel ".$lang['sdi']['name'];
$lang['sdi']['add_title2']="Saisie des critères d'évaluation du nouvel ".$lang['sdi']['name'];
$lang['sdi']['add_title3']="Saisie des coordonnées du fournisseur du nouvel ".$lang['sdi']['name'];
$lang['sdi']['add_title4']="Saisie du texte de réglementation du nouvel ".$lang['sdi']['name'];


$lang['sdi']['mod_title']="Modification des informations générales";
$lang['sdi']['mod_title2']="Modification des critères d'évaluation";
$lang['sdi']['mod_title3']="Modification des coordonnées du fournisseur";
$lang['sdi']['mod_title4']="Modification du texte de réglementation";


$lang['sdi']['recap_commment']="aucun commentaire";
$lang['sdi']['confirmation']="confirmer l'inscription";




/*	nommage étapes add
 *  	*/

$lang['sdi']['add_step1']="infos générales";
$lang['sdi']['add_step2']="critères d'évaluation";
$lang['sdi']['add_step3']="coordonnées fournisseur";
$lang['sdi']['add_step4']="texte de réglementation";
$lang['sdi']['btn_step1']="étape2";
$lang['sdi']['btn_step2']="étape3";
$lang['sdi']['btn_step3']="étape4";
$lang['sdi']['btn_fin']="finir saisie";


/*	nommage rubrique sup
 *  	*/
$lang['sdi']['sup_sdi_warning']="Etes-vous sûr de vouloir supprimer définitivement cet ".$lang['sdi']['name']."?";
$lang['sdi']['sup_sdi_warning2']="La suppression de cet indicateur induit la suppression de son fournisseur, du texte de réglementation, de ses valeurs associées, et de ses critères d'évaluation.";
$lang['sdi']['sup_sdi_warning3']="Attention, si vous supprimez cet indicateur, son thème associé ne contiendra plus d'indicateurs.";


/*	nommage élément rubrique
 *  	*/

$lang['sdi']['name2']="nom de l'indicateur";
$lang['sdi']['type']="type d'indicateur";
$lang['sdi']['value_type']="type de valeur";
$lang['sdi']['dashboard_viz']="type de visualisation - tableau de bord";
$lang['sdi']['detail_viz']="type de visualisation - détail";
$lang['sdi']['description']="Description";
$lang['sdi']['comment']="Commentaires";
$lang['sdi']['theme']="thème de rattachement";
$lang['sdi']['sdtheme']="finalité";
$lang['sdi']['range']="Rang de l'indicateur";
$lang['sdi']['goal']="Objectif de l'indicateur (mesures à prendre)";
$lang['sdi']['consulting']="Conseils d'amélioration";
$lang['sdi']['attached_to_dashboard']="Attaché au tableau de bord";
$lang['sdi']['not_attached_to_dashboard']="non attaché au tableau de bord";
$lang['sdi']['info_mesure']="Informations de mesure";
$lang['sdi']['unit']="unité de mesure";
$lang['sdi']['max_value']="maximum";
$lang['sdi']['min_value']="minimum";
$lang['sdi']['initial_threshold_value']="valeur seuil initiale";
$lang['sdi']['threshold_value']="valeur seuil";
$lang['sdi']['threshold_relative']="comportement relatif du seuil";
$lang['sdi']['threshold_relative_comment']="Cochez cette case, si l'objectif est atteint pour une valeur supérieure au seuil.";
$lang['sdi']['threshold_relative_Y']="l'objectif est atteint si la valeur est supérieure au seuil.";
$lang['sdi']['threshold_relative_N']="l'objectif n'est pas atteint si la valeur est supérieure au seuil.";
$lang['sdi']['frequency']="fréquence de collecte";

$lang['sdi']['bool_indicator']='Indicateur de type booléen.';
$lang['sdi']['boolindicator_notice']='Indicateur de type booléen. Vous pouvez définir un masque en utilisant la syntaxe suivante <strong>{0=non;1=oui}</strong> dans le champ <a href=\"%s\">commentaire</a>.';
$lang['sdi']['boolindicator_mask']='Le masque suivant a été défini : %s.';
$lang['sdi']['boolindicator_nomask']='Aucun masque défini.';


$lang['sdi']['e_title']="Critères d'évaluation des données";
$lang['sdi']['e_scale_compare']="comparabilité";
$lang['sdi']['e_fiability']="fiabilité";
$lang['sdi']['e_accessibility']="accessibilité";
$lang['sdi']['e_lisibility']="lisibilité";
$lang['sdi']['e_relevance']="pertinence";
$lang['sdi']['e_global_performance']="performance globale";


$lang['sdi']['p_title']="fournisseur des données";
$lang['sdi']['p_name']="nom du fournisseur";
$lang['sdi']['p_service']="service";
$lang['sdi']['p_description']="description du fournisseur";
$lang['sdi']['p_incharge']="responsable";
$lang['sdi']['p_address']="adresse complète";
$lang['sdi']['p_phone']="téléphone";
$lang['sdi']['p_fax']="fax";
$lang['sdi']['p_email']="email";


$lang['sdi']['r_title']="nom de la réglementation";
$lang['sdi']['r_body']="texte de réglementation";
$lang['sdi']['r_referer_uri']="lien internet";
$lang['sdi']['r_mask_uri']="texte de lien";


/** select-box option and values (keys) */
$lang['sdi']['select_type']['quantitative']='quantitatif';
//$lang['sdi']['select_type']['qualitative']='qualitatif';
$lang['sdi']['select_type']['boolean']='booléen';
$lang['sdi']['select_value_type']['unique']='unique';
$lang['sdi']['select_value_type']['multiple']='multiple';
$lang['sdi']['select_dashboard_viz']['raw']='valeur brute';
$lang['sdi']['select_dashboard_viz']['gauge']='jauge';
$lang['sdi']['select_dashboard_viz']['sparkline']='sparkline';
$lang['sdi']['select_detail_viz']['column']='colonne';
$lang['sdi']['select_detail_viz']['line']='ligne';
$lang['sdi']['select_detail_viz']['area']='aire';


/*	nommage quickbox
 *  	*/
$lang['sdi']['qb_add_title']=" derniers ajouts effectués";
$lang['sdi']['qb_mod_title']=" dernières modifications effectuées";


/*	divers
 *  	*/
$lang['sdi']['select_choice']="-- Faites votre choix dans la liste ci dessous --";
$lang['sdi']['facultatif']="facultatif";
$lang['sdi']['theme_filter']="Afficher par thème";
$lang['sdi']['notheme']="Aucun thème choisi";
$lang['sdi']['aff_sdi_e']="Afficher les critères d'évaluation";
$lang['sdi']['modify_sdi_e']="Modifier les critères d'évaluation";

$lang['sdi']['aff_sdi_r']="Afficher les textes de réglementation";
$lang['sdi']['modify_sdi_r']="Modifier les textes de réglementation";
$lang['sdi']['aff_sdi_p']="Afficher les coordonnées du fournisseur";
$lang['sdi']['modify_sdi_p']="Modifier les coordonnées du fournisseur";
$lang['sdi']['noresultp']="Vous pouvez saisir un fournisseur en cliquant sur le bouton modifier ci contre";
$lang['sdi']['noresultr']="Vous pouvez saisir un texte de réglementation en cliquant sur le bouton modifier ci contre";
$lang['sdi']['url']='<acronym title="Uniform Resource Locator">URL</acronym>';
$lang['sdi']['clone_suffix']= "clone";
$lang['sdi']['clone_confirmation']= "Souhaitez-vous vraiment cloner cet indicateur?";

/*	messages
 *  	*/


$lang['sdi']['object_notname']="Vous devez impérativement saisir un nom pour cet indicateur.";
$lang['sdi']['object_notdescription']="Vous devez impérativement saisir une description pour cet indicateur.";
$lang['sdi']['object_nottheme']="Vous devez impérativement choisir un thème pour cet indicateur.";
$lang['sdi']['object_notrange']="Vous devez impérativement choisir un rang pour cet indicateur.";
$lang['sdi']['object_notunit']="Vous devez impérativement saisir une unité de mesure.";
$lang['sdi']['object_notmax_value']="La valeur maximale doit être une valeur numérique.";
$lang['sdi']['object_notmin_value']="La valeur minimale doit être une valeur numérique.";
$lang['sdi']['object_notthreshold_value']="La valeur de seuil doit être une valeur numérique.";
$lang['sdi']['object_notfrequency']="La fréquence de relevé doit être précisée (en nombre de jours).";
$lang['sdi']['server_noresponse']='L\' '.$lang['sdi']['url'].' semble incorrecte (le fichier ne répond pas). Veuillez vérifier sa syntaxe';




$lang['sdi']['object_note_scale_compare']="L'indice de comparabilité doit être une valeur numérique.";
$lang['sdi']['object_note_fiability']="L'indice de fiabilité doit être une valeur numérique.";
$lang['sdi']['object_note_accessibility']="L'indice d'accessibilité doit être une valeur numérique.";
$lang['sdi']['object_note_lisibility']="L'indice de lisibilité doit être une valeur numérique.";
$lang['sdi']['object_note_relevance']="L'indice de pertinence doit être une valeur numérique.";
$lang['sdi']['object_note_global_performance']="L'indice de performance globale doit être une valeur numérique.";




$lang['sdi']['object_notp_name']="Vous devez impérativement entrer un nom pour ce fournisseur.";
$lang['sdi']['object_notp_address']="Vous devez impérativement entrer une adresse pour ce fournisseur.";
$lang['sdi']['object_notp_phone']="Le numéro de téléphone n'est pas valide.";
$lang['sdi']['object_notp_fax']="Le numéro de fax n'est pas valide.";
$lang['sdi']['object_notp_mail']="L'adresse email n'est pas valide.";


$lang['sdi']['object_notr_title']="Vous devez impérativement entrer un nom pour cette réglementation.";
$lang['sdi']['object_notr_body']="Vous devez impérativement entrer un texte pour cette réglementation.";


/*	rubrique d'aide
 *  	*/
$lang['sdi']['help_add1']="Pour ajouter un indicateur, vous devez saisir chacun de ces paramètres dans le formulaire ci-dessus";
$lang['sdi']['help_add2']="l'ajout d'un indicateur se réalise en 4 étapes : infos générales -> évaluation -> fournisseur -> réglementation";
$lang['sdi']['help_add3']="Après avoir valider le formulaire d'ajout, vérifiez les paramètres d'ajout dans le récapitulatif";
$lang['sdi']['help_add4']="Si le récapitulatif ne vous convient pas, vous pouvez cliquer sur \"revoir les paramètres\" pour les modifier";
$lang['sdi']['help_add5']="Vous pouvez ne pas remplir les 3 denières étapes en cliquant sur '".$lang['sdi']['btn_fin']."' à la première étape, vous serez alors directement redirigé vers le récapitulatif";
$lang['sdi']['help_add6']="Les champs marqués d'un astérisque sont obligatoires";


$lang['sdi']['help_list1']="Pour afficher un indicateur en détails, cliquez sur le nom de cet indicateur";
$lang['sdi']['help_list2']="Vous pouvez supprimer un indicateur en cliquant sur l'icône de suppression associée";
$lang['sdi']['help_list3']="Vous pouvez modifier un indicateur en cliquant sur l'icône de modification associée";
$lang['sdi']['help_list4']="Pour ajouter un indicateur, cliquez sur le lien \"ajouter un indicateur\" dans la barre de titre";
$lang['sdi']['help_list5']="Vous pouvez faire une recherche dans la liste d'indicateurs à tout moment en cliquant sur \"recherche\"";

$lang['sdi']['help_mod1']="Pour modifier les informations générales d'un indicateur, vous pouvez modifier chacun de ces paramètres dans le formulaire ci-dessus";
$lang['sdi']['help_mod2']="Après avoir validé le formulaire de modification, vérifiez les paramètres d'ajout dans le récapitulatif";
$lang['sdi']['help_mod3']="Si le récapitulatif ne vous convient pas, vous pouvez cliquer sur \"revoir les paramètres\" pour les modifier";
$lang['sdi']['help_mod4']="Pour modifier les informations de réglementation, fournisseurs, et critères d'évaluation, cliquer sur \"modifier ces informations\" en haut de page.";
$lang['sdi']['help_mod5']="Pour modifier les informations générales de cet indicateur, cliquer sur l'icône de modification qui lui est associée sur la page \"détails d'un indicateur\".";


$lang['sdi']['help_mod_p1']="Pour modifier les coordonnées fournisseurs d'un indicateur, vous pouvez modifier chacun de ces paramètres dans le formulaire ci-dessus";
$lang['sdi']['help_mod_e1']="Pour modifier les critères d'évaluation d'un indicateur, vous pouvez modifier chacun de ces paramètres dans le formulaire ci-dessus";
$lang['sdi']['help_mod_r1']="Pour modifier les textes de réglementation d'un indicateur, vous pouvez modifier chacun de ces paramètres dans le formulaire ci-dessus";


$lang['sdi']['help_det1']="Vous pouvez modifier les informations générales de cet indicateur en cliquant sur l'icône de modification associée";
$lang['sdi']['help_det2']="Vous pouvez supprimer cet indicateur en cliquant sur l'icône de suppression associée";
$lang['sdi']['help_det3']="Pour afficher le thème de l'indicateur consulté, cliquez sur le nom de ce thème";
$lang['sdi']['help_det4']="Pour afficher les informations de réglementation, fournisseurs, et critères d'évaluation, cliquer sur \"afficher ces informations\" en bas de page";
$lang['sdi']['help_det5']="Pour modifier les informations de réglementation, fournisseurs, et critères d'évaluation, cliquer sur les icônes de modification associées";


$lang['sdi']['help_sup1']="En cliquant sur valider, l'indicateur est définitivement suppprimer ainsi que son fournisseur, son texte de réglementation, ses valeurs associées, et ses critères d'évaluation";
$lang['sdi']['help_sup2']="Un message apparait si le thème associé à cet indicateur ne contient plus d'indicateurs après suppression de celui-ci";
?>
